==> haskell-js-flot-0.8.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-L9d0drjPrNY8X0lXiXeWLY
key:                  js-flot-0.8.3-L9d0drjPrNY8X0lXiXeWLY
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  08f4910d8e1cbebeaff01079cdecce8b
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-9.0.1/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-L9d0drjPrNY8X0lXiXeWLY
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-59BX6eNV5k1AHgrvzz49bI
key:                  js-flot-0.8.3-59BX6eNV5k1AHgrvzz49bI
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  34e2df155086ce8033bffd85046e6d86
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-9.0.2/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-59BX6eNV5k1AHgrvzz49bI
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
